#
# spec file for package python-gertty
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-gertty
Version:        1.4.0
Release:        2.3
Summary:        Gertty is a console-based interface to the Gerrit Code Review system
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://www.openstack.org/
Source:         https://files.pythonhosted.org/packages/source/g/gertty/gertty-%{version}.tar.gz
# dependencies from py2pack:
BuildRequires:  python-GitPython >= 0.3.7
BuildRequires:  python-PyYAML >= 3.1.0
BuildRequires:  python-SQLAlchemy >= 1.0.4
BuildRequires:  python-alembic >= 0.6.4
BuildRequires:  python-devel
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-ordereddict
%endif
BuildRequires:  python-pbr >= 0.11
BuildRequires:  python-ply >= 3.4
BuildRequires:  python-python-dateutil
BuildRequires:  python-requests >= 2.5.3
BuildRequires:  python-setuptools
BuildRequires:  python-six
BuildRequires:  python-urwid >= 1.2.1
BuildRequires:  python-voluptuous >= 0.7
Requires:       python-GitPython >= 0.3.7
Requires:       python-PyYAML >= 3.1.0
Requires:       python-SQLAlchemy >= 1.0.4
Requires:       python-alembic >= 0.6.4
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
Requires:       python-ordereddict
%endif
Requires:       python-pbr >= 0.11
Requires:       python-ply >= 3.4
Requires:       python-python-dateutil
Requires:       python-requests >= 2.5.3
Requires:       python-six
Requires:       python-urwid >= 1.2.1
Requires:       python-voluptuous >= 0.7
# manually added dependencies:
BuildRequires:  dos2unix
BuildRequires:  python-sphinx
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Gertty is a console-based interface to the Gerrit Code Review system.

As compared to the web interface, the main advantages are:

 * Workflow -- the interface is designed to support a workflow similar
   to reading network news or mail.  In particular, it is designed to
   deal with a large number of review requests across a large number
   of projects.

 * Offline Use -- Gertty syncs information about changes in subscribed
   projects to a local database and local git repos.  All review
   operations are performed against that database and then synced back
   to Gerrit.

 * Speed -- user actions modify locally cached content and need not
   wait for server interaction.

 * Convenience -- because Gertty downloads all changes to local git
   repos, a single command instructs it to checkout a change into that
   repo for detailed examination or testing of larger changes.

%prep
%setup -q -n gertty-%{version}

%build
python setup.py build
dos2unix LICENSE # avoid rpmlint warnings
python setup.py build_sphinx

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -m 0644 -D build/sphinx/man/gertty.1 $RPM_BUILD_ROOT%{_mandir}/man1/gertty.1

%files
%defattr(-,root,root,-)
%doc LICENSE AUTHORS ChangeLog README.rst
%{_bindir}/gertty
%{_mandir}/man1/*
%{python_sitelib}/*
%{_datadir}/gertty

%changelog
* Wed Jul 27 2016 dmueller@suse.com
- remove ordereddict dep
* Tue Jul 26 2016 aspiers@suse.com
- Update to 1.4.0
  * Large changes with many patchsets load faster.
  * The change screen now displays changes which may conflict with the
    current change.
  * Added support for a command socket so that external applications may
    request Gertty to open a change.  An example of how to
    configure Gerrit URLs to automatically open in Gertty when
    clicked in the unicode-rxvt terminal emulater is provided in
    the documentation.
  * Added an optional vi-style keymap and navigation commands.
  * Added "project topics" -- the ability to group projects in the
    project list.
  * Added support for the process mark on the project list.
  * Email addresses are displayed in the change screen.
  * Added support for the "projects:" search term.
  * Added support for searching by last-seen.  This can be used to
    create a dashboard of changes that have been recently viewed in
    Gertty.  See the example config files for how to set this up.
  * The project and change lists are now searchable with the
    interactive search command.
  * The change list now displays more columns if there is room.
  * Added a navigation breadcrumb footer.
  * Added a "Reply" button to the change screen to facilitate quoted
    replies to messages.
  * When re-reviewing a change, the review dialog defaults to previous
    values.
  * Added support for batch abandon and restore.
  * Unified diff display now groups changed lines better.
  * Added lockfile support to prevent multiple copies of Gertty from
    accessing the same database.
  * Added support for form-based authentication.
  * Added an option to specify the URL for cloning git repos.
  * In the default keymap, the sorting commands now take two keystrokes
    (e.g., "Sn" for sort by number) to facilitate more sorting options.
  * Multi-keystroke commands now display suggestion completions.
  * Dashboards may now specify their default sorting option.
  * Sphinx-based documentation now availablet at
    http://gertty.readthedocs.io/
  * Added an option to disable mouse support.
  * Many bug fixes
- Build the man page
* Wed Apr 20 2016 tbechtold@suse.com
- update to 1.3.2:
  * Use diff long options and uncap GitPython
* Fri Feb 26 2016 tbechtold@suse.com
- update to 1.3.1:
  * Fix list index out of range
  * Fix multi-key handling in diff view
  * Support >= 2.9 query batching
  * Fix multi-key handling at top level
  * Fix config validation to accept new keymap format
  * Fix commit message editing in >= 2.11
  * Support multiple key input
  * Add help entries for kill, yank, isearch
  * Add navigation to interactive search
  * Add interactive search to diff view
  * Add a simple kill ring
  * Match links by url instead of domain
  * Separate search and refine search commands
  * Fix syncing changes with comments on a missing file
  * Change key binding for reverse sort to shift-r ('R')
  * Update .gitreview for new namespace
  * Make permalink clickable
  * Support '-' as negation operator in query
  * Redisplay after spawning browser
  * Fix get_repo call even more
  * Supply a default query on search
  * Show all held changes in held-changes view
  * Add missing get_repo calls
  * Specify color for unstable test job
  * Allow bulk-edit of topics
  * Ignore EPERM when pruning refs
  * Removes the need to pass around the app object
  * Refactor: move getRepo out of the App object
  * Mention the bug tracker in the README file
  * Fix crash on displaying renamed file
  * Fix waiting for tasks
  * Update PBR requirement to >=0.11
  * Advance cursor on change list toggle
  * Allow reviewing one change in change list
  * Fix updating flags on threaded changes
  * Add ability to review multiple changes at once
  * Fix refresh on project and change lists
  * Fix diff display of deleted empty files
  * Add database pruning
  * Attach comments to files
  * Add files table
  * Batch sync change by commit tasks
  * Make "limit" a noop in queries
  * Fix searching by reviewer account id
  * Fix age searching
  * Fix searching for message
  * Do not enqueue duplicate tasks
  * Support regexes in search
  * Add support for SQLAlchemy 1.0.4
  * Make ButtonDialog scrollable
  * Be more verbose on non-tagged versions
  * Explain how to install on Arch Linux
  * Don't display draft approvals in change list
  * Add extra note about pep8
  * flake8: Fix F401,F403
  * flake8: Fix F821,F841
  * Add notes on pep8 and pyflakes
  * tox: Fix flake8 setup
  * Explain how to install on openSUSE
  * Don't enqueue full syncs when going offline
  * Fix error in double upload
  * Fix crash on opening a change with missing commits
  * Display file header in top line of diff
  * Open internal URLs in commentlinks
  * Highlight own name on change screen
  * Add a key to return to the project list
  * Do not clear history when opening a dashboard
  * Make change-id a search link in change screen
  * Make topic a search link in change screen
  * Make project name a search link in change screen
  * Sync change when missing refs
  * Try git protocol last when fetching
  * Fix changeset fetching
  * Add permalink to change view
  * Support searching by URL
  * Add checkout and cherry-pick to change list
  * Sync starred changes regardless of subscription
  * Sync own changes regardless of subscription
  * Add held changes
  * Highlight starred changes in list
  * Fix repository checking
  * Add is:watched to p_is_term()
  * Do not display InsecurePlatformWarning
  * Display warnings as a popup
  * Handle change id in simple searches
  * Minor typo - may -> many
  * Right align line numbers
  * Add change list options to configuration
  * Add missing requirement for six
  * Add mouse wheel scrolling
  * Switch "Updated" column to fixed width
  * Don't display project column in project change list
  * Display times in local tz
  * Add a 30 second timeout for requests
  * Upgrade to requests 2.5.3
  * Only sync parent commit once
  * Add indexes to revision table
  * Hide webbrowser output
  * Fix searching with uppercase booleans
  * Expand sample keymaps to ameliorate OSX features
- Adjust Requires and BuildRequires according to requirements.txt
* Wed Apr  1 2015 aspiers@suse.com
- Initial version
